@@ -9,7 +9,8 @@ import {
     TupleSelector,
     TupleStorageFactoryService,
     VortexService,
-    VortexStatusService
+    VortexStatusService,
+    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs"
 
 import { Observable, Subject } from "rxjs"
@@ -478,26 +479,18 @@ export class ChunkedIndexLoaderService extends NgLifeCycleEvents {
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeChunkedIndexChunkTuples(encodedChunkedIndexChunkTuples: ChunkedIndexEncodedChunkTuple[]): Promise<void> {
-        let retPromise: any
-        retPromise = this.storage.transaction(true)
-            .then((tx) => {
-                
-                let promises = []
-                
-                for (let encodedChunkedIndexChunkTuple of encodedChunkedIndexChunkTuples) {
-                    promises.push(
-                        tx.saveTuplesEncoded(
-                            new ChunkedIndexChunkTupleSelector(encodedChunkedIndexChunkTuple.chunkKey),
-                            encodedChunkedIndexChunkTuple.encodedData
-                        )
-                    )
-                }
-                
-                return Promise.all(promises)
-                    .then(() => tx.close())
-            })
-        return retPromise
+    private storeChunkedIndexChunkTuples(tuplesToSave: ChunkedIndexEncodedChunkTuple[]): Promise<void> {
+        const Selector = ChunkedIndexChunkTupleSelector;
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
+            });
+        }
+
+        return this.storage.batchSaveTuplesEncoded(batchStore);
     }
     
     /** Get ChunkedIndexs When Ready
